pub enum PoEFunctionType {
GeometricMean {},
Sigmoid {
max_points: Uint64,
p: Decimal,
s: Decimal,
},
SigmoidSqrt {
max_points: Uint64,
s: Decimal,
},
AlgebraicSigmoid {
max_points: Uint64,
a: Decimal,
p: Decimal,
s: Decimal,
},
}Variants
GeometricMean
GeometricMean returns the geometric mean of staked amount and engagement points
Sigmoid
Sigmoid returns a sigmoid-like value of staked amount times engagement points. See the Proof-of-Engagement white-paper for details.
SigmoidSqrt
SigmoidSqrt returns a sigmoid-like value of the geometric mean of staked amount and
engagement points.
It is equal to Sigmoid with p = 0.5, but implemented using integer sqrt instead of
fixed-point fractional power.
AlgebraicSigmoid
AlgebraicSigmoid returns a sigmoid-like value of staked amount times engagement points.
It is similar to Sigmoid, but uses integer sqrt instead of a fixed-point exponential.
Implementations
Sourceimpl PoEFunctionType
impl PoEFunctionType
pub fn to_poe_fn(&self) -> Result<Box<dyn PoEFunction>, ContractError>