pub struct MixerFunctionResponse {
pub points: u64,
}Fields
points: u64Trait Implementations
Sourceimpl Clone for MixerFunctionResponse
impl Clone for MixerFunctionResponse
Sourcefn clone(&self) -> MixerFunctionResponse
fn clone(&self) -> MixerFunctionResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MixerFunctionResponse
impl Debug for MixerFunctionResponse
Sourceimpl<'de> Deserialize<'de> for MixerFunctionResponse
impl<'de> Deserialize<'de> for MixerFunctionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MixerFunctionResponse
impl JsonSchema for MixerFunctionResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MixerFunctionResponse
impl PartialEq for MixerFunctionResponse
Sourceimpl Serialize for MixerFunctionResponse
impl Serialize for MixerFunctionResponse
impl Eq for MixerFunctionResponse
impl StructuralPartialEq for MixerFunctionResponse